# harmonize-dosage

Harmonize dosage, not effect, for mendelian randomization.

harmonize-dosage is a program to harmonize the dosage and exposure files to the
outcome file in a Mendelian Randomization experiment. It accepts both dosage and
vcf.gz/vcf/bcf files as input. In the latter case, a dosage file is created from
the vcf.

# Install
